Module: SchemaPlus::Indexes::ActiveRecord::Base::ClassMethods
- Defined in:
- lib/schema_plus/indexes/active_record/base.rb
Instance Method Summary collapse
-
#indexes ⇒ Object
Returns a list of IndexDefinition objects, for each index defined on this model's table.
-
#reset_index_information ⇒ Object
(reset_index_information gets called by by Middleware::Model::ResetColumnInformation).
Instance Method Details
#indexes ⇒ Object
Returns a list of IndexDefinition objects, for each index defined on this model's table.
13 14 15 |
# File 'lib/schema_plus/indexes/active_record/base.rb', line 13 def indexes @indexes ||= connection.indexes(table_name) end |
#reset_index_information ⇒ Object
(reset_index_information gets called by by Middleware::Model::ResetColumnInformation)
18 19 20 |
# File 'lib/schema_plus/indexes/active_record/base.rb', line 18 def reset_index_information @indexes = nil end |